@@ -20,14 +20,14 @@ class BaseTV(object):
 
     .. code-block:: python
 
-       state_detection_rules = {'com.amazon.tv.launcher': ['standby'],
+       state_detection_rules = {'com.amazon.tv.launcher': ['idle'],
                                 'com.netflix.ninja': ['media_session_state'],
                                 'com.ellation.vrv': ['audio_state'],
                                 'com.hulu.plus': [{'playing': {'wake_lock_size' : 4}},
                                                   {'paused': {'wake_lock_size': 2}}],
                                 'com.plexapp.android': [{'paused': {'media_session_state': 3, 'wake_lock_size': 1}},
                                                         {'playing': {'media_session_state': 3}},
-                                                        'standby']}
+                                                        'idle']}
 
     The keys are app IDs, and the values are lists of rules that are evaluated in order.
 
@@ -40,9 +40,9 @@ class BaseTV(object):
 
     **Valid rules:**
 
-    * ``'standby'``, ``'playing'``, ``'paused'``, ``'idle'``, or ``'off'`` = always report the specified state when this app is open
-    * ``'media_session_state'`` = try to use the :attr:`media_session_state` property to determine the state
-    * ``'audio_state'`` = try to use the :attr:`audio_state` property to determine the state
+    * ``'idle'``, ``'playing'``, ``'paused'``, ``'standby'``, or ``'off'`` = always report the specified state when this app is open
+    * ``'media_session_state'`` = try to use the :meth:`media_session_state` property to determine the state
+    * ``'audio_state'`` = try to use the :meth:`audio_state` property to determine the state
     * ``{'<VALID_STATE>': {'<PROPERTY1>': VALUE1, '<PROPERTY2>': VALUE2, ...}}`` = check if each of the properties is equal to the specified value, and if so return the state
 
       * The valid properties are ``'media_session_state'``, ``'audio_state'``, and ``'wake_lock_size'``
@@ -62,18 +62,17 @@ class BaseTV(object):
         The port for the ADB server
     state_detection_rules : dict, None
         A dictionary of rules for determining the state (see above)
-    auth_timeout_s : float
-        Authentication timeout (in seconds)
 
     """
 
-    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, auth_timeout_s=constants.DEFAULT_AUTH_TIMEOUT_S):
+    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
         self.host = host
         self.port = int(port)
         self.adbkey = adbkey
         self.adb_server_ip = adb_server_ip
         self.adb_server_port = adb_server_port
         self._state_detection_rules = state_detection_rules
+        self.device_properties = {}
 
         # make sure the rules are valid
         if self._state_detection_rules:
@@ -93,17 +92,23 @@ class BaseTV(object):
             # pure-python-adb
             self._adb = ADBServer(host, port, adb_server_ip, adb_server_port)
 
-        # establish the ADB connection
-        self.adb_connect(auth_timeout_s=auth_timeout_s)
-
-        # get device properties
-        self.device_properties = self.get_device_properties()
-
     # ======================================================================= #
     #                                                                         #
     #                               ADB methods                               #
     #                                                                         #
     # ======================================================================= #
+    @property
+    def available(self):
+        """Whether the ADB connection is intact.
+
+        Returns
+        -------
+        bool
+            Whether or not the ADB connection is intact
+
+        """
+        return self._adb.available
+
     def adb_shell(self, cmd):
         """Send an ADB command.
 
@@ -266,13 +271,13 @@ class BaseTV(object):
         Parameters
         ----------
         current_app : str, None
-            The :attr:`current_app` property
+            The :meth:`current_app` property
         media_session_state : int, None
-            The :attr:`media_session_state` property
+            The :meth:`media_session_state` property
         wake_lock_size : int, None
-            The :attr:`wake_lock_size` property
+            The :meth:`wake_lock_size` property
         audio_state : str, None
-            The :attr:`audio_state` property
+            The :meth:`audio_state` property
 
         Returns
         -------
@@ -297,7 +302,7 @@ class BaseTV(object):
                 if media_session_state == 3:
                     return constants.STATE_PLAYING
                 if media_session_state is not None:
-                    return constants.STATE_STANDBY
+                    return constants.STATE_IDLE
 
             # Use the `audio_state` property
             if rule == 'audio_state' and audio_state in constants.VALID_STATES:
@@ -320,11 +325,11 @@ class BaseTV(object):
         conditions : dict
             A dictionary of conditions to be checked (see the ``state_detection_rules`` parameter in :class:`~androidtv.basetv.BaseTV`)
         media_session_state : int, None
-            The :attr:`media_session_state` property
+            The :meth:`media_session_state` property
         wake_lock_size : int, None
-            The :attr:`wake_lock_size` property
+            The :meth:`wake_lock_size` property
         audio_state : str, None
-            The :attr:`audio_state` property
+            The :meth:`audio_state` property
 
         Returns
         -------
@@ -356,7 +361,6 @@ class BaseTV(object):
     #                               Properties                                #
     #                                                                         #
     # ======================================================================= #
-    @property
     def audio_output_device(self):
         """Get the current audio playback device.
 
@@ -370,7 +374,6 @@ class BaseTV(object):
 
         return self._audio_output_device(stream_music)
 
-    @property
     def audio_state(self):
         """Check if audio is playing, paused, or idle.
 
@@ -383,19 +386,6 @@ class BaseTV(object):
         audio_state_response = self._adb.shell(constants.CMD_AUDIO_STATE)
         return self._audio_state(audio_state_response)
 
-    @property
-    def available(self):
-        """Check whether the ADB connection is intact.
-
-        Returns
-        -------
-        bool
-            Whether or not the ADB connection is intact
-
-        """
-        return self._adb.available
-
-    @property
     def awake(self):
         """Check if the device is awake (screensaver is not running).
 
@@ -407,7 +397,6 @@ class BaseTV(object):
         """
         return self._adb.shell(constants.CMD_AWAKE + constants.CMD_SUCCESS1_FAILURE0) == '1'
 
-    @property
     def current_app(self):
         """Return the current app.
 
@@ -421,7 +410,6 @@ class BaseTV(object):
 
         return self._current_app(current_app_response)
 
-    @property
     def is_volume_muted(self):
         """Whether or not the volume is muted.
 
@@ -435,7 +423,6 @@ class BaseTV(object):
 
         return self._is_volume_muted(stream_music)
 
-    @property
     def media_session_state(self):
         """Get the state from the output of ``dumpsys media_session``.
 
@@ -451,7 +438,6 @@ class BaseTV(object):
 
         return media_session_state
 
-    @property
     def screen_on(self):
         """Check if the screen is on.
 
@@ -463,7 +449,6 @@ class BaseTV(object):
         """
         return self._adb.shell(constants.CMD_SCREEN_ON + constants.CMD_SUCCESS1_FAILURE0) == '1'
 
-    @property
     def volume(self):
         """Get the absolute volume level.
 
@@ -478,7 +463,6 @@ class BaseTV(object):
 
         return self._volume(stream_music, audio_output_device)
 
-    @property
     def volume_level(self):
         """Get the relative volume level.
 
@@ -488,11 +472,10 @@ class BaseTV(object):
             The volume level (between 0 and 1), or ``None`` if it could not be determined
 
         """
-        volume = self.volume
+        volume = self.volume()
 
         return self._volume_level(volume)
 
-    @property
     def wake_lock_size(self):
         """Get the size of the current wake lock.
 
@@ -537,7 +520,7 @@ class BaseTV(object):
 
     @staticmethod
     def _audio_state(audio_state_response):
-        """Parse the :attr:`audio_state` property from the output of the command :py:const:`androidtv.constants.CMD_AUDIO_STATE`.
+        """Parse the :meth:`audio_state` property from the output of the command :py:const:`androidtv.constants.CMD_AUDIO_STATE`.
 
         Parameters
         ----------
@@ -1120,7 +1103,7 @@ class BaseTV(object):
         """
         # if necessary, determine the max volume
         if not self.max_volume:
-            _ = self.volume
+            _ = self.volume()
             if not self.max_volume:
                 return None
 
@@ -1146,7 +1129,7 @@ class BaseTV(object):
 
         """
         if current_volume_level is None or not self.max_volume:
-            current_volume = self.volume
+            current_volume = self.volume()
         else:
             current_volume = round(self.max_volume * current_volume_level)
 
@@ -1175,7 +1158,7 @@ class BaseTV(object):
 
         """
         if current_volume_level is None or not self.max_volume:
-            current_volume = self.volume
+            current_volume = self.volume()
         else:
             current_volume = round(self.max_volume * current_volume_level)
 
@@ -1189,6 +1172,53 @@ class BaseTV(object):
         # return the new volume level
         return max(current_volume - 1, 0.) / self.max_volume
 
+    # ======================================================================= #
+    #                                                                         #
+    #                          Miscellaneous methods                          #
+    #                                                                         #
+    # ======================================================================= #
+    def learn_sendevent(self, timeout_s=8):
+        """Capture an event (e.g., a button press) via ``getevent`` and convert it into ``sendevent`` commands.
+
+        For more info, see:
+
+        * http://ktnr74.blogspot.com/2013/06/emulating-touchscreen-interaction-with.html?m=1
+        * https://qatesttech.wordpress.com/2012/06/21/turning-the-output-from-getevent-into-something-something-that-can-be-used/
+
+        Parameters
+        ----------
+        timeout_s : int
+            The timeout in seconds to wait for events
+
+        Returns
+        -------
+        str
+            The events converted to ``sendevent`` commands
+
+        """
+        getevent = self.adb_shell("( getevent ) & pid=$!; ( sleep {} && kill -HUP $pid ) 2>/dev/null & watcher=$!; if wait $pid 2>/dev/null; then echo 'your command finished'; kill -HUP -P $watcher; wait $watcher; else echo 'your command was interrupted'; fi".format(timeout_s))
+
+        return " && ".join([self._parse_getevent_line(line) for line in getevent.splitlines() if line.startswith("/") and ":" in line])
+
+    @staticmethod
+    def _parse_getevent_line(line):
+        """Parse a line of the output received in ``learn_sendevent``.
+
+        Parameters
+        ----------
+        line : str
+            A line of output from ``learn_sendevent``
+
+        Returns
+        -------
+        str
+            The properly formatted ``sendevent`` command
+
+        """
+        device_name, event_info = line.split(":", 1)
+        integers = [int(x, 16) for x in event_info.strip().split()[:3]]
+        return "sendevent {} {} {} {}".format(device_name, *integers)
+
 
 # ======================================================================= #
 #                                                                         #
